import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';
import { InputProps } from 'ant-design-vue';

export const fileUploadSchema: FormSchema[] = [
  {
    label: '文件位置',
    field: 'type',
    defaultValue: '本地',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '本地',
          value: '本地',
        },
        {
          label: '文件系统',
          value: '文件系统',
        },
      ],
    },
  },
  {
    label: '文件存储地址',
    field: 'address',
    show: ({ model }) => {
      return model.type === '本地';
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '65_hdfs',
          value: '65_hdfs',
        },
      ],
    },
  },
  {
    label: '上传文件',
    field: 'file',
    show: ({ model }) => {
      return model.type === '本地';
    },
    slot: 'file',
  },
  {
    label: '选择加载方式',
    field: 'loadingType',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    defaultValue: '全量文件加载',
    slot: 'loadingType',
  },
  {
    label: '数据源',
    field: 'dataSource',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '088-hdfs',
          value: '088-hdfs',
        },
      ],
    },
  },
  {
    label: '路径',
    field: 'path',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    slot: 'path',
  },
  {
    label: '文件过滤(选填)',
    field: 'filter',
    show: ({ model }) => {
      return model.type === '文件系统';
    },
    component: 'Input',
    componentProps: {
      placeholder: '包含完整路径的文件名正则表达式，例如/hadoop/data_*',
    },
  },
  {
    label: '列分隔符',
    field: 'delimiter',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '列起止符',
    field: 'startStop',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '编码格式',
    field: 'encoding',
    show: ({ model }) => {
      return model.fileType !== 'excel';
    },
    component: 'Input',
  },
  {
    label: '导入sheet名称',
    field: 'sheet',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'sheet',
  },
  {
    label: '是否包含表头',
    field: 'head',
    defaultValue: '是',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
  },
  {
    label: '表头起止行数',
    field: 'header',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel' && model.head === '是';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel' && model.head === '是';
    },
    slot: 'header',
  },
  {
    label: '数据起止行数',
    field: 'row',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'row',
  },
  {
    label: '文件起止列数',
    field: 'column',
    show: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    required: ({ model }) => {
      return model.type === '本地' && model.fileType === 'excel';
    },
    slot: 'column',
  },
];
export const fileTableColumn: BasicColumn[] = [
  {
    dataIndex: 'c1',
  },
  {
    dataIndex: 'c2',
  },
  {
    dataIndex: 'c3',
  },
  {
    dataIndex: 'c4',
  },
  {
    dataIndex: 'c5',
  },
  {
    dataIndex: 'c6',
  },
  {
    dataIndex: 'c7',
  },
  {
    dataIndex: 'c8',
  },
  {
    dataIndex: 'c9',
  },
  {
    dataIndex: 'c10',
  },
];
export const dataSourceUploadSchema: FormSchema[] = [
  {
    label: '数据源',
    field: 'dataSource',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '64_inceptor',
          value: '64_inceptor',
        },
      ],
    },
  },
  {
    label: '清空目标表',
    field: 'clear',
    defaultValue: '是',
    slot: 'clear',
  },
  {
    label: '目标库',
    field: 'database',
    required: true,
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'gxx',
          value: 'gxx',
        },
      ],
    },
  },
  {
    label: '允许最大并发度',
    field: 'concurrent',
    component: 'Input',
  },
  {
    label: 'HDFS数据源',
    field: 'hdfsSource',
    required: true,
    helpMessage: 'HDFS数据源',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: '65_hdfs',
          value: '65_hdfs',
        },
      ],
    },
  },
  {
    label: '目标表快照',
    field: 'snapshot',
    defaultValue: '否',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '是',
          value: '是',
        },
        {
          label: '否',
          value: '否',
        },
      ],
    },
  },
];
export const dataSourceFieldFormSchema: FormSchema[] = [
  {
    label: '是否自动建表',
    field: 'createTable',
    helpMessage: '是否自动建表',
    defaultValue: '否',
    slot: 'createTable',
  },
  {
    label: '目标表名',
    field: 'tableName',
    required: true,
    show: ({ model }) => {
      return model.createTable === '是';
    },
    component: 'Input',
  },
];
export const dataSourceTableColumn: BasicColumn[] = [
  {
    title: '源端',
    dataIndex: 'source',
    slots: { customRender: 'source' },
    width: 200,
  },
  {
    title: '目标端',
    dataIndex: 'target',
    slots: { customRender: 'target' },
    width: 200,
  },
  {
    title: '分区数据配置',
    dataIndex: 'areaConfig',
    slots: { customRender: 'areaConfig' },
    width: 50,
  },
  {
    title: '清理配置',
    dataIndex: 'clearConfig',
    slots: { customRender: 'clearConfig' },
    width: 50,
  },
];
export const dataSourceFieldTableColumn: BasicColumn[] = [
  {
    title: '源字段',
    dataIndex: 'sourceField',
    slots: { customRender: 'sourceField' },
  },
  {
    title: '目标字段',
    dataIndex: 'targetField',
    slots: { customRender: 'targetField' },
  },
  {
    title: '字段注解',
    dataIndex: 'fieldRemark',
    slots: { customRender: 'fieldRemark' },
  },
];
export const dataSourceSqlFormSchema: FormSchema[] = [
  {
    label: '表类型',
    field: 'type',
    component: 'Select',
    componentProps: {
      options: [
        {
          label: 'TEXT',
          value: 'TEXT',
        },
        {
          label: 'ORC',
          value: 'ORC',
        },
        {
          label: 'TORC',
          value: 'TORC',
        },
      ],
    },
  },
  {
    field: '',
    slot: 'title1',
  },
  {
    label: '分区',
    field: 'area',
    defaultValue: '无',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '无',
          value: '无',
        },
        {
          label: '单值分区',
          value: '单值分区',
        },
        {
          label: '范围分区',
          value: '范围分区',
        },
      ],
    },
  },
  {
    label: '分区键',
    field: 'areaKey',
    show: ({ model }) => {
      return model.area !== '无';
    },
    slot: 'areaKey',
  },
  {
    label: '分区范围',
    field: 'areaRange',
    show: ({ model }) => {
      return model.area === '范围分区';
    },
    slot: 'areaRange',
  },
  {
    label: '分区间隔',
    field: 'areaSpace',
    show: ({ model }) => {
      return model.area === '范围分区';
    },
    component: 'Input',
  },
  {
    field: '',
    slot: 'title2',
  },
  {
    label: '分桶',
    field: 'bucket',
    defaultValue: '否',
    component: 'RadioGroup',
    componentProps: {
      options: [
        {
          label: '否',
          value: '否',
        },
        {
          label: '是',
          value: '是',
        },
      ],
    },
  },
  {
    label: '分桶键',
    field: 'bucketKey',
    component: 'Input',
    show: ({ model }) => {
      return model.bucket === '是';
    },
  },
  {
    label: '分桶个数',
    field: 'bucketNum',
    show: ({ model }) => {
      return model.bucket === '是';
    },
    slot: 'bucketNum',
  },
  {
    field: '',
    slot: 'title3',
  },
  {
    field: 'otherConfigType',
    component: 'Select',
    defaultValue: '表注释',
    show: false,
  },
  {
    field: 'otherConfig',
    slot: 'otherConfig',
  },
];
export const showLogFormSchema: FormSchema[] = [
  {
    field: 'tableName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入表名',
    },
  },
];
export const showLogTable: BasicColumn[] = [
  {
    title: '源表名',
    dataIndex: 'sourceTable',
  },
  {
    title: '目标表名',
    dataIndex: 'targetTable',
  },
  {
    title: '表类型',
    width: 90,
    dataIndex: 'tableType',
  },
  {
    title: '分区类型',
    width: 90,
    dataIndex: 'areaType',
  },
  {
    title: '分区键',
    width: 100,
    dataIndex: 'partitionKey',
  },
  {
    title: '调试结果',
    dataIndex: 'debuggingResult',
  },
];
export const showTableFormSchema: FormSchema[] = [
  {
    field: 'columnName',
    label: '',
    component: 'Input',
    componentProps: {
      placeholder: '输入列名',
    },
  },
];
export const showTableColumn: BasicColumn[] = [
  {
    title: '源列名',
    dataIndex: 'sourceColumnName',
    slots: { customRender: 'sourceColumnName' },
  },
  {
    title: '目标列名',
    dataIndex: 'targetColumnName',
    slots: { customRender: 'targetColumnName' },
  },
];
export const dataFilterRuleModalFormSchema: FormSchema[] = [
  {
    label: '规则名称',
    field: 'name',
    required: true,
    component: 'Input',
  },
  {
    label: '自定义规则',
    field: 'rule',
    component: 'InputTextArea',
    componentProps: {
      placeholder: '请输入自定义过滤规则',
      rows: 4,
    } as InputProps,
  },
];
export const addFieldRuleModal: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldRuleAlert',
    slot: 'newFieldRuleAlert',
  },
  {
    field: 'newFieldName',
    label: '新增字段名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'newFieldType',
    label: '新增字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: true,
  },
  {
    field: 'fieldExpression',
    label: '字段表达式',
    component: 'Input',
    required: true,
  },
];
export const dataChangeRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'selectiveDataTable',
    label: '选择数据表',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'table_1', value: 'table_1' },
        { label: 'table_2', value: 'table_2' },
        { label: 'table_3', value: 'table_3' },
        { label: 'table_4', value: 'table_4' },
      ],
    },
    required: true,
  },
  {
    field: 'conversionResultWriting',
    label: '转换结果写入',
    component: 'RadioGroup',
    defaultValue: '覆盖已有字段',
    componentProps: {
      options: [
        { label: '覆盖已有字段', value: '覆盖已有字段' },
        { label: '写入新增字段', value: '写入新增字段' },
      ],
    },
    required: true,
  },
  {
    field: 'selectExistingField',
    label: '选择已有字段',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'total_amount', value: 'total_amount' },
        { label: 'payment_id', value: 'payment_id' },
        { label: 'position', value: 'position' },
        { label: 'employee_id', value: 'employee_id' },
      ],
    },
    required: ({ model }) => {
      return model.conversionResultWriting === '覆盖已有字段';
    },
    show: ({ model }) => {
      return model.conversionResultWriting === '覆盖已有字段';
    },
  },
  {
    field: 'newFieldName',
    label: '新增字段名称',
    component: 'Input',
    required: ({ model }) => {
      return model.conversionResultWriting === '写入新增字段';
    },
    show: ({ model }) => {
      return model.conversionResultWriting === '写入新增字段';
    },
  },
  {
    field: 'newFieldType',
    label: '新增字段类型',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'int', value: 'int' },
        { label: 'bigint', value: 'bigint' },
        { label: 'decimal', value: 'decimal' },
        { label: 'varchar', value: 'varchar' },
        { label: 'string', value: 'string' },
        { label: 'timestamp', value: 'timestamp' },
      ],
    },
    required: ({ model }) => {
      return model.conversionResultWriting === '写入新增字段';
    },
    show: ({ model }) => {
      return model.conversionResultWriting === '写入新增字段';
    },
  },
  {
    field: 'conversionRule',
    label: '转换规则',
    required: true,
    component: 'RadioGroup',
    defaultValue: '自定义',
    componentProps: {
      options: [
        { label: '配置规则', value: '配置规则' },
        { label: '自定义', value: '自定义' },
      ],
    },
  },
  {
    field: 'customRule',
    label: '自定义规则',
    component: 'InputTextArea',
    show: ({ model }) => {
      return model.conversionRule === '自定义';
    },
  },
  {
    field: 'exFunction',
    label: '函数表达式',
    required: true,
    slot: 'exFunction',
    show: ({ model }) => {
      return model.conversionRule === '配置规则';
    },
  },
  {
    field: 'configTable',
    slot: 'configTable',
    show: ({ model }) => {
      return model.conversionRule === '配置规则';
    },
  },
];
export const partDataHandleFormSchema: FormSchema[] = [
  {
    field: 'partitionType',
    label: '分区类型',
    component: 'RadioGroup',
    defaultValue: '单值分区',
    componentProps: {
      options: [{ label: '单值分区', value: '单值分区' }],
    },
  },
  {
    field: 'overwritesTheSingleValuePartitionRawData',
    label: '覆盖单值分区原数据',
    component: 'Switch',
    defaultValue: false,
  },
  {
    field: 'partitionKeyName',
    label: '分区键名',
    component: 'Input',
    show: ({ model }) => {
      return model.overwritesTheSingleValuePartitionRawData;
    },
  },
  {
    field: 'partitionKeyValue',
    label: '分区键值',
    component: 'Input',
  },
];
export const headUploadModalSchema: FormSchema[] = [
  {
    field: 'remark',
    label: '版本变更描述',
    component: 'InputTextArea',
    required: true,
    colProps: { lg: 24, md: 24 },
  },
];
export const headGlobalConfigSchema: FormSchema[] = [
  {
    field: 'name',
    label: '名称',
    component: 'Input',
    componentProps: {
      readonly: true,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
    },
    defaultValue: 'TDT1',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'remark',
    label: '描述',
    component: 'InputTextArea',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'period',
    label: '调度周期',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'Cron表达式', value: '1' },
        { label: '每天一次', value: '2' },
        { label: '无周期', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'cron',
    label: 'Cron表达式',
    component: 'Input',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.period === '1',
  },
  {
    field: 'periodTime',
    label: '调度时间',
    component: 'TimePicker',
    colProps: { lg: 24, md: 24 },
    ifShow: ({ model }) => model.period === '2',
  },
  {
    field: 'timeoutType',
    component: 'Checkbox',
    label: '超时取消',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.timeoutType;
        formActionType.updateSchema([{ field: 'minute', ifShow: flag }]);
      },
    }),
    renderComponentContent: '开启',
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'minute',
    label: '分钟',
    component: 'InputNumber',
    componentProps: {
      min: 0,
      max: 1000,
    },
    ifShow: false,
    labelWidth: 40,
    colProps: { lg: 12, md: 12 },
  },
  {
    field: 'DDLOption',
    component: 'Checkbox',
    label: 'DDL变化策略配置',
    componentProps: ({ formModel, formActionType }) => ({
      onChange: () => {
        const flag = formModel.DDLOption;
        formActionType.updateSchema([{ field: 'isDeleteTable', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'isDeleteTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'addTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'changeTableField', ifShow: flag }]);
        formActionType.updateSchema([{ field: 'globalOptionsAlert', ifShow: flag }]);
      },
    }),
    renderComponentContent: '开启',
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'globalOptionsAlert',
    slot: 'globalOptionsAlert',
    ifShow: false,
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'isDeleteTable',
    label: '源端数据表被删除',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [{ label: '取消运行子任务', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'isDeleteTableField',
    label: '源端数据表字段被删除',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [
        { label: '取消运行子任务', value: '1' },
        { label: '取消运行子任务并不能影响任务结果', value: '2' },
        { label: '空值填充', value: '3' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'addTableField',
    label: '源端数据表新增字段',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [
        { label: '取消运行子任务', value: '1' },
        { label: '取消运行子任务并不能影响任务结果', value: '2' },
        { label: '忽略新增字段', value: '3' },
        { label: '自动更新', value: '4' },
      ],
    },
    colProps: { lg: 24, md: 24 },
  },
  {
    field: 'changeTableField',
    label: '源端数据表字段或类型变更',
    component: 'RadioGroup',
    defaultValue: '1',
    ifShow: false,
    componentProps: {
      options: [{ label: '取消运行子任务', value: '1' }],
    },
    colProps: { lg: 24, md: 24 },
  },
];
export const runOptionsColumns: BasicColumn[] = [
  {
    title: '参数名称',
    dataIndex: 'name',
    width: 120,
  },
  {
    title: '参数类型',
    dataIndex: 'type',
    width: 120,
  },
  {
    title: '参数值',
    dataIndex: 'data',
    width: 120,
    edit: true,
    editable: true,
  },
];
export const SingleTableFieldMappingRuleFormSchema: FormSchema[] = [
  {
    field: 'ruleName',
    label: '规则名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'selectiveDataTable',
    label: '源表名',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'table_1', value: 'table_1' },
        { label: 'table_2', value: 'table_2' },
        { label: 'table_3', value: 'table_3' },
        { label: 'table_4', value: 'table_4' },
      ],
    },
    required: true,
  },
  {
    field: 'mappingTable',
    slot: 'mappingTable',
  },
];
export const singleGoalFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'targetFieldName',
    edit: true,
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    edit: true,
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];
export const singleSourceFieldNameMappingRuleColumns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'fieldName',
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
  },
  {
    title: '注释',
    dataIndex: 'annotation',
  },
];
export const configTableColumn: BasicColumn[] = [
  {
    title: '参数名',
    dataIndex: 'field',
  },
  {
    title: '实际值',
    dataIndex: 'value',
    editable: true,
    edit: true,
    editComponent: 'Input',
    editComponentProps: {
      placeholder: '请输入',
    }
  },
];
